/*
  'Acqua' kwin client

  Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#include <qpainter.h>

#include "AcquaButton.h"
#include "Acqua.h"

using namespace KWinInternal;

static const char * inactive_xpm[] = {
"22 16 61 1",
" 	c None",
".	c #DFDFDF",
"+	c #DEDEDE",
"@	c #C4C4C4",
"#	c #ABABAB",
"$	c #989898",
"%	c #8C8C8C",
"&	c #ADADAD",
"*	c #C5C5C5",
"=	c #D7D7D7",
"-	c #B2B2B2",
";	c #A5A5A5",
">	c #BFBFBF",
",	c #CFCFCF",
"'	c #DBDBDB",
")	c #BDBDBD",
"!	c #B1B1B1",
"~	c #D6D6D6",
"{	c #B0B0B0",
"]	c #B7B7B7",
"^	c #DADADA",
"/	c #DCDCDC",
"(	c #DDDDDD",
"_	c #C2C2C2",
":	c #A3A3A3",
"<	c #D8D8D8",
"[	c #D9D9D9",
"}	c #A4A4A4",
"|	c #AAAAAA",
"1	c #B9B9B9",
"2	c #D5D5D5",
"3	c #BABABA",
"4	c #A9A9A9",
"5	c #969696",
"6	c #C9C9C9",
"7	c #D4D4D4",
"8	c #959595",
"9	c #8E8E8E",
"0	c #CECECE",
"a	c #D1D1D1",
"b	c #D0D0D0",
"c	c #D2D2D2",
"d	c #D3D3D3",
"e	c #8B8B8B",
"f	c #C6C6C6",
"g	c #949494",
"h	c #A7A7A7",
"i	c #B3B3B3",
"j	c #CCCCCC",
"k	c #9E9E9E",
"l	c #CBCBCB",
"m	c #CDCDCD",
"n	c #9F9F9F",
"o	c #AEAEAE",
"p	c #CACACA",
"q	c #AFAFAF",
"r	c #A8A8A8",
"s	c #C0C0C0",
"t	c #C8C8C8",
"u	c #9D9D9D",
"v	c #C7C7C7",
"..+..++.@#$%$&*.......",
"++++.+=-;>,',);!~+++++",
"++++.+{]^''''/^]!(.+++",
"+.+++_:<[^[<[<<=}_+.++",
"+++++|1~~2~~22~~34.(++",
"(((+(5627277727768((((",
"''/'^90aabcaab7dbe^'''",
"[[[^<5f,baaaaa,a*g[<[^",
"~~2~~hi0,abaa,j0i;=~~=",
"222223kjl0jmmmlln3~22~",
"dd7dd7|olllpplpq47d22d",
",,b,b,6rk!sts!u|p,,bb,",
"00j00000]}geg:]0m0000m",
"pplllp6l6pjpjllllllllp",
"lljmjlmlmjlmppp6llllll",
"ttt6ttttttttvttt6ttttt"};


AcquaButton::AcquaButton(QWidget * parent, const QString& tip)
  : KWinWidgetButton (parent, 0, 0, tip),
    mouseOver_  (false),
    mouseDown_  (false)
{
  setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
  setBackgroundMode(NoBackground);
  setFixedSize(18, 16);
}

AcquaButton::~AcquaButton()
{
  // Empty.
}

void
AcquaButton::mousePressEvent(QMouseEvent * e)
{
  mouseDown_ = true;
  repaint();
  KWinWidgetButton::mousePressEvent(e);
}

void
AcquaButton::mouseReleaseEvent(QMouseEvent * e)
{
  mouseDown_ = false;
  repaint();

  if (rect().contains(e->pos()))
  {
    clickEvent(e->button());
  }
  KWinWidgetButton::mouseReleaseEvent(e);
}

  void
AcquaButton::enterEvent(QEvent * e)
{
  mouseOver_ = true;
  repaint();
  KWinWidgetButton::enterEvent(e);
}

  void
AcquaButton::leaveEvent(QEvent * e)
{
  mouseOver_ = false;
  repaint();
  KWinWidgetButton::leaveEvent(e);
}

  void
AcquaButton::paintEvent(QPaintEvent *)
{
#if 0  
  QPen highlightPen;

  p.setBrush(NoBrush);
  p.setPen(Qt::black);

  if (mouseDown_)
    highlightPen = QPen(colorGroup().light());

  else
  {
    if (mouseOver_)
      highlightPen = QPen(colorGroup().highlight());
    else
      highlightPen = QPen(NoPen);
  }
#endif
  QPainter p(this);

//  p.fillRect(rect(), colorGroup().background());

  Acqua *owner=dynamic_cast<Acqua *>(parent());
  if(!owner)return;

    // Draw icon.

  QPoint center(rect().center());

  int bwby2(pixmap_.width() / 2);    // Bitmap Width BY 2
  int bhby2(pixmap_.height() / 2);   // Bitmap Height BY 2

  if(owner->isActive()){
    if(mouseDown_){
      p.drawPixmap(center.x() - bwby2 + 1, center.y() - bhby2 + 1, pixmap_down);
    }
    else if(mouseOver_){
      p.drawPixmap(center.x() - bwby2 + 1, center.y() - bhby2 + 1, pixmap_over);
    }
    else {
      p.drawPixmap(center.x() - bwby2 + 1, center.y() - bhby2 + 1, pixmap_);
    }
  }
  else 
      p.drawPixmap(center.x() - bwby2 + 1, center.y() - bhby2 + 1, QPixmap(inactive_xpm));
}

  QSize
AcquaButton::sizeHint() const
{
  return QSize(16, 16);
}

  QSize
AcquaButton::minimumSizeHint() const
{
  return QSize(16, 16);
}

  void
AcquaButton::resizeEvent(QResizeEvent *)
{
  repaint();
}

#include "AcquaButton.moc"
// vim:ts=2:sw=2:tw=78:set et:
